@@ -34,7 +34,6 @@
 #include <stdlib.h>	/* atoi() */
 #include <sys/types.h>
 #include <sys/stat.h>
-#include <ctype.h> /* tolower() */
 
 #include "gnome-i18nP.h"
 #include "gnome-util.h"
@@ -506,10 +505,10 @@ access_config (access_type mode, const char *section_name,
 	return def;
 }
 
-/* an extended version of access_config for looking up values in ~/.gnome.
+/* an extended version of access_config for looking up values in ~/.gnome2.
  * For writes it falls through to the standard behaviour.
  * For lookups, it first checks for the value in
- * $(datadir)/gnome/config-override, and if it isn't there in ~/.gnome,
+ * $(datadir)/gnome/config-override, and if it isn't there in ~/.gnome2,
  * then checks $(datadir)/gnome/config, and as a last fallback uses def.
  * This gives system administrators high level control over the default
  * configuration values for GNOME
@@ -1349,7 +1348,9 @@ gnome_config_drop_all (void)
  * gnome_config_get_int:
  * @path: A gnome configuration path to an item.
  *
- * Returns: The value of a configuration item as an integer.
+ * Retrieves an integer value configuration item.
+ *
+ * Returns: The value of a configuration item.
  */
 /**
  * gnome_config_private_get_int:
@@ -1366,6 +1367,8 @@ gnome_config_drop_all (void)
  * @def: A pointer to a flag that will be set if the default value for the item
  * is returned.
  *
+ * Retrieves an integer value configuration item.
+ *
  * Returns: The value of a configuration item as an integer or @def if the
  * configuration item does not exist.
  */
@@ -1412,8 +1415,9 @@ gnome_config_get_int_with_default_ (const char *path, gboolean *def, gboolean pr
  * gnome_config_get_float:
  * @path: A gnome configuration path to an item.
  *
- * Returns: The value of a configuration item as a floating-point
- * number.
+ * Retrieves a floating-point valued configuration item.
+ *
+ * Returns: The value of a configuration item.
  */
 /**
  * gnome_config_private_get_float:
@@ -1431,6 +1435,8 @@ gnome_config_get_int_with_default_ (const char *path, gboolean *def, gboolean pr
  * @def: A pointer to a flag that will be set if the default value for the item
  * is returned.
  *
+ * Retrieves a floating-point valued configuration item.
+ *
  * Returns: The value of a configuration item as a floating-point
  * number or @def if the configuration item does not exist.
  */
@@ -1694,7 +1700,9 @@ gnome_config_get_string_with_default_ (const char *path, gboolean *def,
  * gnome_config_get_bool:
  * @path: A gnome configuration path to an item.
  *
- * Returns: The value of a configuration item as a boolean.
+ * Retrieves a boolean configuration value.
+ *
+ * Returns: The value of a configuration item.
  */
 /**
  * gnome_config_private_get_bool:
@@ -1710,7 +1718,9 @@ gnome_config_get_string_with_default_ (const char *path, gboolean *def,
  * @def: A pointer to a flag that will be set if the default value for the item
  * is returned.
  *
- * Returns: The value of a configuration item as a boolean, or @def if the
+ * Retrieves a boolean configuration value.
+ *
+ * Returns: The value of a configuration item, or @def if the
  * configuration item does not exist.
  */
 /**
@@ -1746,7 +1756,7 @@ gnome_config_get_bool_with_default_ (const char *path, gboolean *def,
 		return 0;
 	}
 
-	if (tolower(*r) == 't' || tolower(*r) == 'y' || atoi(r)) {
+	if (g_ascii_tolower(*r) == 't' || g_ascii_tolower(*r) == 'y' || atoi(r)) {
 	  v = 1;
 	} else {
 	  /* If it's not true it has to be false :) */
